@@ -2,21 +2,22 @@
 
 import gc
 from collections import OrderedDict
-from .basic import BasicRenderableTable
 
 from kivy.animation import Animation
 from kivy.uix.relativelayout import RelativeLayout
 
 from ebs.iot.linuxnode.animations.composite import CompositeAnimationManager
 
+from .translatable import TranslatableRenderableTable
 
-class BasicAnimatedTable(BasicRenderableTable):
+
+class AnimatedTable(TranslatableRenderableTable):
     def __init__(self, node, spec):
         self._current_entries = OrderedDict()
         self._animations = CompositeAnimationManager()
         self._animation_layer = None
         self._animation_lock = False
-        super(BasicAnimatedTable, self).__init__(node, spec)
+        super(AnimatedTable, self).__init__(node, spec)
 
     @property
     def active_entries(self):
@@ -63,10 +64,10 @@ class BasicAnimatedTable(BasicRenderableTable):
     def _detach_entries(self, entries):
         for tags, entry_bin in entries.items():
             self._detach_entry(entry_bin)
-        self._node.log.debug("Detached {0} Entries, Remaining T={1},A={2} Entries"
-                             "".format(len(entries),
-                                       len(self._gui_table_entries.children),
-                                       len(self.animation_layer.children)))
+        self.log.debug("Detached {0} Entries, Remaining T={1},A={2} Entries"
+                       "".format(len(entries),
+                                 len(self._gui_table_entries.children),
+                                 len(self.animation_layer.children)))
 
     def _exit_animation(self, idx):
         x, y = self._entry_pos(idx)
@@ -87,6 +88,10 @@ class BasicAnimatedTable(BasicRenderableTable):
         entry_bin.pos = x - dx, y - dy
         self.animation_layer.add_widget(entry_bin)
 
+    def _position_entry(self, idx, entry_bin):
+        entry_bin.pos = self._entry_pos(idx)
+        self.animation_layer.add_widget(entry_bin)
+
     def _entry_animation(self, idx):
         px, py = self._entry_pos(idx)
         animation = Animation(x=px, y=py, t='out_cubic', duration=1.)
@@ -108,10 +113,10 @@ class BasicAnimatedTable(BasicRenderableTable):
     def _attach_entries(self, entries):
         for tags, entry_bin in entries.items():
             self._attach_entry(entry_bin)
-        self._node.log.debug("Attached {0} Entries, Remaining T={1},A={2} Entries"
-                             "".format(len(entries),
-                                       len(self._gui_table_entries.children),
-                                       len(self.animation_layer.children)))
+        self.log.debug("Attached {0} Entries, Remaining T={1},A={2} Entries"
+                       "".format(len(entries),
+                                 len(self._gui_table_entries.children),
+                                 len(self.animation_layer.children)))
 
     def _entries_change_handler(self, _, value):
         pass
@@ -132,7 +137,9 @@ class BasicAnimatedTable(BasicRenderableTable):
     def _build_entries(self, entries):
         rv = OrderedDict()
         for entry in entries:
-            tags = tuple([getattr(entry, x) for x in self.spec.dedup_keys])
+            tags = [getattr(entry, x) for x in self.spec.dedup_keys]
+            tags.append(self.language)
+            tags = tuple(tags)
             entry_bin = entry.build(self.palette)
             entry_bin.size_hint = (None, None)
             entry_bin.size = self._entry_size()
@@ -141,9 +148,9 @@ class BasicAnimatedTable(BasicRenderableTable):
 
     def redraw_entries(self, entries):
         if self._animation_lock:
-            self._node.log.warn("Animation lock is active! Force breaking.")
+            self.log.warn("Animation lock is active! Force breaking.")
 
-        self._node.log.debug("Redrawing Table, Got {0} Entries".format(len(entries)))
+        self.log.debug("Redrawing Table, Got {0} Entries".format(len(entries)))
         self._alternate_fallback_handler(None, entries)
         self._detach_entries(self._current_entries)
         new_entries = self._build_entries(entries)
@@ -161,8 +168,13 @@ class BasicAnimatedTable(BasicRenderableTable):
         for idx, (tags, entry_bin) in enumerate(new_entries.items()):
             if tags in deferred_tags.keys():
                 oidx, oentry_bin = deferred_tags[tags]
-                new_entries[tags] = oentry_bin
-                self._animations.add(self._transfer_animation(idx), oentry_bin)
+                self.animation_layer.remove_widget(oentry_bin)
+                self._position_entry(oidx, entry_bin)
+                if oidx < idx:
+                    animation = self._delay_entry(idx) + self._transfer_animation(idx)
+                else:
+                    animation = self._transfer_animation(idx)
+                self._animations.add(animation, entry_bin)
                 continue
             self._preposition_entry(idx, entry_bin)
             animation = self._delay_entry(idx) + self._entry_animation(idx)
@@ -174,8 +186,11 @@ class BasicAnimatedTable(BasicRenderableTable):
             self._destroy_dangling_entities()
             gc.collect()
 
-        self._animations.when_done(_finish)
-        self._animation_lock = True
-        self._animations.start()
         self._current_entries = new_entries
-        new_entries = None
+
+        if len(self._animations):
+            self._animations.when_done(_finish)
+            self._animation_lock = True
+            self._animations.start()
+        else:
+            _finish()
